[
  %( host => "localhost", tags => %( task => "task1", :database, :5432port ) ),
  %( host => "localhost", tags => %( task => "task2", :webserver, :80port  ) ),
  %( host => "localhost", tags => %( task => "task3", :database, :5432port ) ),
  %( host => "localhost", tags => %( task => "task4", :webserver, :80port  ) ),
]
