[
  #"127.0.0.1",
  #"localhost",
  #"docker:alpine",
  #"127.0.0.1",
  #'ec2-34-224-16-129.compute-1.amazonaws.com'
  #"localhost",
  #"localhost",
  %(
    host => "localhost",
    project => "test123",
    tags => %(
      message => "hello world",
      name => "example build",
      :foo<hello world ok kkkkk>
    ),
  ),
]
